package com.ruoyi.frequency.bankcard.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.frequency.bankcard.entity.BankCard;
import com.ruoyi.frequency.bankcard.service.BankCardService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 银行卡Controller
 * 
 * @author liwenlong
 * @date 2024-04-10
 */
@RestController
@RequestMapping("/frequency/bankcard")
public class BankCardController extends BaseController
{
    @Autowired
    private BankCardService bankCardService;

    /**
     * 查询银行卡列表
     */
    @PreAuthorize("@ss.hasPermi('frequency:bankcard:list')")
    @GetMapping("/list")
    public TableDataInfo<BankCard> list(BankCard bankCard)
    {
        startPage();
        List<BankCard> list = bankCardService.selectBankCardList(bankCard);
        return getDataTable(list);
    }

    /**
     * 导出银行卡列表
     */
    @PreAuthorize("@ss.hasPermi('frequency:bankcard:export')")
    @Log(title = "银行卡", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(BankCard bankCard)
    {
        List<BankCard> list = bankCardService.selectBankCardList(bankCard);
        ExcelUtil<BankCard> util = new ExcelUtil<BankCard>(BankCard.class);
        return util.exportExcel(list, "银行卡数据");
    }

    /**
     * 获取银行卡详细信息
     */
    @PreAuthorize("@ss.hasPermi('frequency:bankcard:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult<BankCard> getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(bankCardService.selectBankCardById(id));
    }

    /**
     * 新增银行卡
     */
    @PreAuthorize("@ss.hasPermi('frequency:bankcard:add')")
    @Log(title = "银行卡", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BankCard bankCard)
    {
        return toAjax(bankCardService.insertBankCard(bankCard));
    }

    /**
     * 修改银行卡
     */
    @PreAuthorize("@ss.hasPermi('frequency:bankcard:edit')")
    @Log(title = "银行卡", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BankCard bankCard)
    {
        return toAjax(bankCardService.updateBankCard(bankCard));
    }

    /**
     * 删除银行卡
     */
    @PreAuthorize("@ss.hasPermi('frequency:bankcard:remove')")
    @Log(title = "银行卡", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}/{delFlag}")
    public AjaxResult remove(@PathVariable("ids") Long[] ids,@PathVariable("delFlag") Integer delFlag)
    {
        return toAjax(bankCardService.deleteBankCardByIds(ids,delFlag));
    }
}
